[Python-checkins] cpython (3.5): Make Lib/test/ssltests.py more useful and faster for OpenSSL testing

christian.heimes python-checkins at python.org
Thu Sep 22 10:54:15 EDT 2016


https://hg.python.org/cpython/rev/e629aafdf777
changeset:   104011:e629aafdf777
branch:      3.5
parent:      104006:6c880906b214
user:        Christian Heimes <christian at python.org>
date:        Thu Sep 22 16:49:35 2016 +0200
summary:
  Make Lib/test/ssltests.py more useful and faster for OpenSSL testing

files:
  Lib/test/ssltests.py |  27 +++++++++++++++++++++------
  1 files changed, 21 insertions(+), 6 deletions(-)


diff --git a/Lib/test/ssltests.py b/Lib/test/ssltests.py
--- a/Lib/test/ssltests.py
+++ b/Lib/test/ssltests.py
@@ -1,17 +1,32 @@
 # Convenience test module to run all of the SSL-related tests in the
 # standard library.
 
+import ssl
 import sys
 import subprocess
 
-TESTS = ['test_asyncio', 'test_ftplib', 'test_hashlib', 'test_httplib',
-         'test_imaplib', 'test_nntplib', 'test_poplib', 'test_smtplib',
-         'test_smtpnet', 'test_urllib2_localnet', 'test_venv']
+TESTS = [
+    'test_asyncio', 'test_ensurepip.py', 'test_ftplib', 'test_hashlib',
+    'test_hmac', 'test_httplib', 'test_imaplib', 'test_nntplib',
+    'test_poplib', 'test_ssl', 'test_smtplib', 'test_smtpnet',
+    'test_urllib2_localnet', 'test_venv', 'test_xmlrpc'
+]
 
 def run_regrtests(*extra_args):
-    args = [sys.executable, "-m", "test"]
+    print(ssl.OPENSSL_VERSION)
+    args = [
+        sys.executable,
+        '-Werror', '-bb',  # turn warnings into exceptions
+        '-m', 'test',
+    ]
     if not extra_args:
-        args.append("-unetwork")
+        args.extend([
+            '-r',  # randomize
+            '-w',  # re-run failed tests with -v
+            '-u', 'network',  # use network
+            '-u', 'urlfetch',  # download test vectors
+            '-j', '0'  # use multiple CPUs
+        ])
     else:
         args.extend(extra_args)
     args.extend(TESTS)
@@ -1,17 +1,32 @@
-# Convenience test module to run all of the SSL-related tests in the
+# Convenience test module to run all of the OpenSSL-related tests in the
 # standard library.
 

-- 
Repository URL: https://hg.python.org/cpython


More information about the Python-checkins mailing list